(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     75944,       1642]
NotebookOptionsPosition[     73895,       1567]
NotebookOutlinePosition[     74253,       1583]
CellTagsIndexPosition[     74210,       1580]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Example file for the ",
 StyleBox["MultiLayerIndentation",
  FontFamily->"Courier"],
 " Package"
}], "Title",
 CellChangeTimes->{{3.571405356133564*^9, 3.571405373476954*^9}}],

Cell[TextData[{
 "Authors: Andrei Constantinescu, Alexander Korsunsky, Olivier Pison, \
Abdelbacet Ouslati\n\nSource for the ",
 StyleBox["MultiLayerIndentation",
  FontFamily->"Courier"],
 " Package\n",
 StyleBox["\n    A. Constantinescu and A.M. Korsunsky - Elasticity with \
Mathematica (r)\n          Cambridge University Press, 2007\n   \n     A.M. \
Korsunsky, A. Constantinescu - The influence of indenter bluntness on the \
apparent contact stiffness of thin coatings, \n           Thin Solid Films \
517 (2009) 4835 \[Dash]4844\n\n    A. Constantinescu, A.M. Korsunsky, O. \
Pison, A. Oueslati - Symbolic and numerical solution of the axisymmetric \
indentation problem of a multilayered elastic solid\n           submitted to \
Int.J. Solids and structures, 2013\n\n    H.Y. Yu, S.C. Sanday, B.B. Rath, \
The effect of substrate on the elastic properties of films determined by the \
indentation test \[LongDash] axisymmetric Boussinesq problem,\n          J. \
Mech. Phys. Solids 38 (6) (1990) 745.\n \n    N.N. Lebedev, I.S. Uflyand, \
Prikladnaya Matematica Mehanica 22 (1958) 320\n  ",
  FontSize->10]
}], "Subsubtitle",
 CellChangeTimes->{{3.571405445916532*^9, 3.571405608883275*^9}, {
  3.571589785499888*^9, 3.571589800371077*^9}}],

Cell[CellGroupData[{

Cell["Load the Package", "Subsection",
 CellChangeTimes->{{3.571405640018538*^9, 3.5714056481776752`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input",
 CellChangeTimes->{{3.571405650393354*^9, 3.57140569928963*^9}}],

Cell[BoxData["\<\"/mydata/LMS/Indentation/Indentation_Olivier/\
IndentationPackage\"\>"], "Output",
 CellChangeTimes->{3.571405700984716*^9, 3.571579346567067*^9, 
  3.571579615990724*^9, 3.571589806063348*^9, 3.572022254435478*^9, 
  3.572111029956607*^9, 3.572111096965892*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "MultiLayerIndentation.m"}]}], "Input",
 CellChangeTimes->{{3.571405650393354*^9, 3.57140569928963*^9}, {
  3.572111649204142*^9, 3.572111650405567*^9}, {3.5721545407049932`*^9, 
  3.5721545410537577`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The functions of the package : MultiLayerIndentation`", "Section",
 CellChangeTimes->{{3.571592092667571*^9, 3.5715921007563467`*^9}, {
  3.57159213212711*^9, 3.5715921542931833`*^9}}],

Cell["\<\
Click on the buttons below to get the usage of the indentation functions\
\>", "Text",
 CellChangeTimes->{{3.5715923793362494`*^9, 3.571592453782235*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "*Indentation"}]], "Input",
 CellChangeTimes->{{3.571589809269698*^9, 3.57158981710398*^9}, {
  3.5715920810109463`*^9, 3.571592083761602*^9}}],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["MultiLayerIndentation`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["MultiLayerIndentation`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["MultiLayerIndentation",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3572114700-5109695", {
            "MultiLayerIndentation", "MultiLayerIndentation`"}},
          ButtonNote->"MultiLayerIndentation`"], 
         ButtonBox["OneLayerIndentation",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3572114700-5109695", {
            "OneLayerIndentation", "MultiLayerIndentation`"}},
          ButtonNote->"MultiLayerIndentation`"]}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.475]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.5721111006172533`*^9}]
}, Open  ]],

Cell["\<\
Click on the buttons below to get the usage of the additional functions of \
the package used for numerical integration using Gauss - points and weights \
\>", "Text",
 CellChangeTimes->{
  3.571592342698988*^9, 3.57159243056439*^9, {3.571592471002303*^9, 
   3.5715925335970573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "MultiLayerIndentation`Gauss*"}]], "Input",
 CellChangeTimes->{{3.571589824854113*^9, 3.571589831234726*^9}, 
   3.571592441480579*^9, {3.57173729400343*^9, 3.571737301266939*^9}, {
   3.571738965180058*^9, 3.571738986614859*^9}}],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["MultiLayerIndentation`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["MultiLayerIndentation`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["GaussIntegrate",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3572114702-7793930", {
            "GaussIntegrate", "MultiLayerIndentation`"}},
          ButtonNote->"MultiLayerIndentation`"], 
         ButtonBox["GaussInterval",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3572114702-7793930", {
            "GaussInterval", "MultiLayerIndentation`"}},
          ButtonNote->"MultiLayerIndentation`"], 
         ButtonBox["GaussStuff",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3572114702-7793930", {"GaussStuff", "MultiLayerIndentation`"}},
          ButtonNote->"MultiLayerIndentation`"], 
         ButtonBox["GaussStuffInterval",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3572114702-7793930", {
            "GaussStuffInterval", "MultiLayerIndentation`"}},
          ButtonNote->"MultiLayerIndentation`"]}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.2375]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.5721111024120007`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Indentation Examples", "Section",
 CellChangeTimes->{{3.571592548804358*^9, 3.571592555574395*^9}}],

Cell[CellGroupData[{

Cell["Indentation of a one layer elastic coating", "Subsection",
 CellChangeTimes->{{3.571592205554501*^9, 3.571592255078258*^9}, {
  3.57159232211239*^9, 3.571592327260355*^9}}],

Cell["Definition of material data :", "Text",
 CellChangeTimes->{{3.572152525281004*^9, 3.5721525458941593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"hsslide", "=", 
    RowBox[{"{", 
     RowBox[{"480", ",", "0.2", ",", "84", ",", "0.4", ",", "\"\<Slide\>\""}],
      "}"}]}], "\n", 
   RowBox[{"hsbound", "=", 
    RowBox[{"{", 
     RowBox[{"480", ",", "0.2", ",", "84", ",", "0.4", ",", "\"\<Bound\>\""}],
      "}"}]}], "\n", 
   RowBox[{
    RowBox[{"depths", "=", 
     RowBox[{"N", "[", 
      RowBox[{"Exp", "[", 
       RowBox[{"Union", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "6"}], ",", "0", ",", "0.5"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "3.5", ",", "0.25"}], "]"}]}], "]"}], "]"}], 
      "]"}]}], ";"}], "\n", "\n", 
   RowBox[{"punch", "=", 
    RowBox[{"{", 
     RowBox[{"\"\<Cone\>\"", ",", 
      RowBox[{"Tan", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"90", "-", "70.3"}], ")"}], " ", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.571737133093151*^9, 3.5717371635234547`*^9}, {
   3.571737371261228*^9, 3.571737391195223*^9}, {3.57173750603622*^9, 
   3.571737514319994*^9}, {3.571745379183432*^9, 3.571745391842339*^9}, 
   3.5717454242969847`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"480", ",", "0.2`", ",", "84", ",", "0.4`", ",", "\<\"Slide\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5717453928723297`*^9, {3.571745428224313*^9, 3.571745443587529*^9}, 
   3.572022269644025*^9, 3.572111037949473*^9, 3.572111105925552*^9, 
   3.572111657948018*^9, 3.572111825713376*^9, 3.57211316084231*^9, 
   3.572152350659753*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"480", ",", "0.2`", ",", "84", ",", "0.4`", ",", "\<\"Bound\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5717453928723297`*^9, {3.571745428224313*^9, 3.571745443587529*^9}, 
   3.572022269644025*^9, 3.572111037949473*^9, 3.572111105925552*^9, 
   3.572111657948018*^9, 3.572111825713376*^9, 3.57211316084231*^9, 
   3.572152350707096*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Cone\"\>", ",", "0.35805183739485164`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5717453928723297`*^9, {3.571745428224313*^9, 3.571745443587529*^9}, 
   3.572022269644025*^9, 3.572111037949473*^9, 3.572111105925552*^9, 
   3.572111657948018*^9, 3.572111825713376*^9, 3.57211316084231*^9, 
   3.572152350765214*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"depths", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Exp", "[", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "2", ",", "0.05"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.571745368246468*^9, 3.5717453700631723`*^9}, {
   3.5717454368763657`*^9, 3.57174544620271*^9}, 3.5721110742238894`*^9, {
   3.572111675016426*^9, 3.572111676050654*^9}, {3.57215235621938*^9, 
   3.5721523574991493`*^9}, {3.572153955400216*^9, 3.572153960250175*^9}, {
   3.572154069010693*^9, 3.572154107561524*^9}, {3.57215424007218*^9, 
   3.5721542616397142`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ndiscret", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"25", ",", " ", "25"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.571745368246468*^9, 3.5717453700631723`*^9}, 
   3.5717454368763657`*^9, {3.5721110783083677`*^9, 3.572111083122912*^9}, {
   3.5721540988083143`*^9, 3.5721541193460913`*^9}, 3.572154275423996*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"l1", " ", "=", " ", 
    RowBox[{"OneLayerIndentation", "[", " ", 
     RowBox[{
     "depths", ",", " ", "punch", ",", " ", "hsslide", ",", " ", "ndiscret"}],
      "]"}]}], " ", ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.571737253401773*^9, 3.5717372713140287`*^9}, {
  3.571737324442664*^9, 3.571737368021344*^9}, {3.57174545647847*^9, 
  3.571745457710182*^9}, {3.572152377172708*^9, 3.572152378789484*^9}, {
  3.572152415749338*^9, 3.572152432116119*^9}, {3.5721542702649612`*^9, 
  3.572154272042254*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"38.609131999999995`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.572111684819846*^9, 3.572111835854908*^9, 
  3.5721131702326717`*^9, 3.572152440738907*^9, 3.572154309939315*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"l1dPStar", " ", "=", " ", 
    RowBox[{"Map", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "  ", 
         RowBox[{"#", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "}"}], " ", "&"}], ",", " ", 
      "l1"}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"ListLogLinearPlot", "[", 
  RowBox[{"l1dPStar", ",", " ", 
   RowBox[{"Frame", " ", "->", " ", "True"}], ",", " ", 
   RowBox[{"GridLines", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "1", "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"84.", ",", " ", "480"}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"All", ",", " ", 
      RowBox[{"{", 
       RowBox[{"50", ",", " ", "500"}], "}"}]}], "}"}]}], ",", "\n", " ", 
   RowBox[{"FrameLabel", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Relative indentation depth\>\"", ",", " ", 
      "\"\<Apparent Contact Modulus\>\""}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.572152436730514*^9, 3.572152447996345*^9}, {
  3.572152482834496*^9, 3.572152484095278*^9}, {3.572154418341847*^9, 
  3.572154505534548*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw10wlUk1cWAOAIFIGwBAJBiWMVBBSwoKgoxb5XEKlSOpQWTFhklyAUIkEg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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-6., 50},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  Frame->True,
  FrameLabel->{
    FormBox["\"Relative indentation depth\"", TraditionalForm], 
    FormBox["\"Apparent Contact Modulus\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0, 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{{0.}, {84., 480}},
  ImageSize->600,
  Method->{},
  PlotRange->{{-6., 2.}, {50, 500}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0, 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.572152452964163*^9, 3.572152484824984*^9, {3.5721543980027323`*^9, 
   3.5721544278156853`*^9}, {3.5721544771487637`*^9, 3.5721545059639053`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Indentation of multilayer layer elastic coating", "Subsection",
 CellChangeTimes->{{3.571592205554501*^9, 3.571592255078258*^9}, {
  3.57159232211239*^9, 3.571592327260355*^9}, {3.571737245308343*^9, 
  3.571737249419303*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"se", " ", "=", " ", 
   RowBox[{"187.", " ", 
    RowBox[{"10", "^", "9"}]}]}], " ", ";", " ", 
  RowBox[{"sn", " ", "=", " ", "0.28"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ee", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"65.", " ", 
      RowBox[{"10", "^", "9"}]}], ",", " ", 
     RowBox[{"277.", " ", 
      RowBox[{"10", "^", "9"}]}]}], "}"}]}], ";", " ", 
  RowBox[{"nn", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0.33", ",", " ", "0.17"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"hh", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"50.", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "6"}]}]}], ",", " ", 
     RowBox[{"30.", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "6"}]}]}]}], " ", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lesE", " ", "=", " ", 
   RowBox[{"Append", "[", " ", 
    RowBox[{
     RowBox[{"Drop", "[", " ", 
      RowBox[{
       RowBox[{"Flatten", "[", " ", 
        RowBox[{"Array", "[", " ", 
         RowBox[{
          RowBox[{"ee", " ", "&"}], " ", ",", " ", "3"}], "]"}], " ", "]"}], 
       ",", " ", 
       RowBox[{"-", "2"}]}], "]"}], ",", " ", "se"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lesNu", " ", "=", " ", 
   RowBox[{"Append", "[", " ", 
    RowBox[{
     RowBox[{"Drop", "[", " ", 
      RowBox[{
       RowBox[{"Flatten", "[", " ", 
        RowBox[{"Array", "[", " ", 
         RowBox[{
          RowBox[{"nn", " ", "&"}], " ", ",", " ", "3"}], "]"}], " ", "]"}], 
       ",", " ", 
       RowBox[{"-", "2"}]}], "]"}], ",", " ", "sn"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lesmu", " ", "=", " ", 
   RowBox[{
    RowBox[{"lesE", " ", "/", 
     RowBox[{"(", " ", 
      RowBox[{"1", " ", "+", " ", "lesNu"}], ")"}]}], "/", "2"}]}], " ", 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"lesz", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1.", ",", " ", "1.6", ",", " ", "2.6", ",", " ", "3.2"}], 
    "}"}]}], " ", ";"}], "\n", 
 RowBox[{"mat", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"lesNu", ",", " ", "lesmu", ",", " ", "lesz"}], "}"}]}]}], "Input",\

 CellChangeTimes->{{3.571738858213798*^9, 3.571738891905264*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.33`", ",", "0.17`", ",", "0.33`", ",", "0.17`", ",", "0.28`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.4436090225563908`*^10", ",", "1.1837606837606839`*^11", ",", 
     "2.4436090225563908`*^10", ",", "1.1837606837606839`*^11", ",", 
     "7.3046875`*^10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "1.6`", ",", "2.6`", ",", "3.2`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.571739010271098*^9, 3.571744849570097*^9, 
  3.571744906518669*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"punch", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<Cone\>\"", ",", " ", 
     RowBox[{"Cot", "[", 
      RowBox[{
       RowBox[{"(", "70.3", ")"}], "*", 
       RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"punchflat", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<Flat\>\"", ",", " ", "1.2*^-6"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"punchsphere", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<Hertz\>\"", ",", " ", "2.*^5"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"punchrock", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<Rock\>\"", ",", " ", 
     RowBox[{"Cot", "[", 
      RowBox[{
       RowBox[{"(", "70.3", ")"}], "*", 
       RowBox[{"Pi", "/", "180"}]}], "]"}], ",", " ", "0.01"}], "}"}]}], 
  ";"}], "\n"}], "Input",
 CellChangeTimes->{{3.571738858213798*^9, 3.571738883469006*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dmax", " ", "=", " ", "14."}], ";", " ", 
  RowBox[{"num1", " ", "=", " ", "100"}], ";", " ", 
  RowBox[{"incr", " ", "=", " ", 
   RowBox[{"dmax", "/", "num1"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"depl", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "incr", ",", " ", "dmax", ",", " ", "incr"}], 
      "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ndiscret", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"40", ",", " ", "40"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.571738858213798*^9, 3.571738883469006*^9}, {
  3.5717390340546293`*^9, 3.571739042440571*^9}, {3.5717448603259068`*^9, 
  3.5717448815078983`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"l4", " ", "=", " ", 
    RowBox[{"MultiLayerIndentation", "[", " ", 
     RowBox[{
     "depl", " ", ",", " ", "punch", ",", " ", "mat", ",", " ", "ndiscret"}], 
     "]"}]}], " ", ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.571738858213798*^9, 3.571738883469006*^9}, {
  3.5717390340546293`*^9, 3.571739042440571*^9}, {3.5717448603259068`*^9, 
  3.571744873531425*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"446.26815600000003`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.571745212806884*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"l4dPStar", " ", "=", " ", 
    RowBox[{"Map", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
         RowBox[{
          RowBox[{"10", "^", 
           RowBox[{"-", "9"}]}], " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], " ", "&"}], ",", " ", 
      "l4"}], "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogLinearPlot", "[", 
   RowBox[{"l4dPStar", ",", " ", 
    RowBox[{"Frame", " ", "->", " ", "True"}], ",", " ", 
    RowBox[{"PlotRange", " ", "->", " ", 
     RowBox[{"{", 
      RowBox[{"40", ",", " ", "220"}], "}"}]}], ",", " ", "\n", " ", 
    RowBox[{"GridLines", " ", "->", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "1", "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"71.", ",", " ", "187"}], "}"}]}], "}"}]}], ",", " ", "\n", 
    " ", 
    RowBox[{"FrameLabel", " ", "->", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Relative indentation depth\>\"", ",", " ", 
       "\"\<Apparent Contact Modulus\>\""}], "}"}]}], ",", " ", "\n", " ", 
    RowBox[{"ImageSize", " ", "->", " ", "600"}]}], "]"}], "\n"}], "\n", 
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwt2Xc8lt//OPB7GYmMlpIKiexIaDgviaaiqOx139d1S1JWZpOWMkqFUBIl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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-4.045554398052668, 40},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  Frame->True,
  FrameLabel->{
    FormBox["\"Relative indentation depth\"", TraditionalForm], 
    FormBox["\"Apparent Contact Modulus\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{-4.605170185988092, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.00\"", 1., AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.00\"", 5., AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"10.00\"", 10., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"50.00\"", 50., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{{0.}, {71., 187}},
  ImageSize->600,
  Method->{},
  PlotRange->{{-4.045554398052668, 2.639057329615259}, {40, 220}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{-4.605170185988092, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"10.00\"", 10., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"50.00\"", 50., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "Input",
 CellChangeTimes->{{3.571738858213798*^9, 3.5717388660973797`*^9}, {
  3.571745237438405*^9, 3.5717452578580313`*^9}, {3.571745290905546*^9, 
  3.571745291736272*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1042, 665},
WindowMargins->{{73, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 193, 6, 143, "Title"],
Cell[763, 30, 1249, 21, 318, "Subsubtitle"],
Cell[CellGroupData[{
Cell[2037, 55, 106, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2168, 60, 122, 2, 32, "Input"],
Cell[2293, 64, 279, 4, 31, "Output"]
}, Open  ]],
Cell[2587, 71, 315, 5, 55, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2939, 81, 190, 2, 73, "Section"],
Cell[3132, 85, 164, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[3321, 92, 171, 3, 32, "Input"],
Cell[3495, 97, 1274, 36, 57, "Print"]
}, Open  ]],
Cell[4784, 136, 295, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[5104, 146, 258, 4, 32, "Input"],
Cell[5365, 152, 1754, 49, 57, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7168, 207, 105, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[7298, 212, 178, 2, 39, "Subsection"],
Cell[7479, 216, 113, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[7617, 221, 1238, 34, 143, "Input"],
Cell[8858, 257, 385, 8, 31, "Output"],
Cell[9246, 267, 385, 8, 31, "Output"],
Cell[9634, 277, 361, 7, 31, "Output"]
}, Open  ]],
Cell[10010, 287, 625, 14, 32, "Input"],
Cell[10638, 303, 360, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[11023, 314, 576, 12, 32, "Input"],
Cell[11602, 328, 229, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11868, 337, 1303, 35, 99, "Input"],
Cell[13174, 374, 14660, 276, 414, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27883, 656, 232, 3, 39, "Subsection"],
Cell[CellGroupData[{
Cell[28140, 663, 2166, 67, 187, "Input"],
Cell[30309, 732, 556, 15, 56, "Output"]
}, Open  ]],
Cell[30880, 750, 900, 26, 121, "Input"],
Cell[31783, 778, 743, 19, 77, "Input"],
Cell[CellGroupData[{
Cell[32551, 801, 434, 10, 32, "Input"],
Cell[32988, 813, 136, 3, 31, "Output"]
}, Open  ]],
Cell[33139, 819, 40716, 743, 584, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
