(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    173038,       4979]
NotebookOptionsPosition[    168244,       4815]
NotebookOutlinePosition[    168602,       4831]
CellTagsIndexPosition[    168559,       4828]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Computation of the interlayer boundary conditions for the construction of \
TransferMatrix in ",
 StyleBox["MultiLayerIndentation",
  FontFamily->"Courier"],
 " Package"
}], "Title",
 CellChangeTimes->{{3.571405356133564*^9, 3.571405373476954*^9}, {
  3.5715931034400387`*^9, 3.571593153508902*^9}}],

Cell[TextData[{
 "Authors: Andrei Constantinescu, Alexander Korsunsky, Olivier Pison, \
Abdelbacet Ouslati\n\nSource for the ",
 StyleBox["MultiLayerIndentation",
  FontFamily->"Courier"],
 " Package\n",
 StyleBox["\n    A. Constantinescu and A.M. Korsunsky - Elasticity with \
Mathematica (r)\n          Cambridge University Press, 2007\n   \n     A.M. \
Korsunsky, A. Constantinescu - The influence of indenter bluntness on the \
apparent contact stiffness of thin coatings, \n           Thin Solid Films \
517 (2009) 4835 \[Dash]4844\n\n    A. Constantinescu, A.M. Korsunsky, O. \
Pison, A. Oueslati - Symbolic and numerical solution of the axisymmetric \
indentation problem of a multilayered elastic solid\n           submitted to \
Int.J. Solids and structures, 2013\n\n    H.Y. Yu, S.C. Sanday, B.B. Rath, \
The effect of substrate on the elastic properties of films determined by the \
indentation test \[LongDash] axisymmetric Boussinesq problem,\n          J. \
Mech. Phys. Solids 38 (6) (1990) 745.\n \n    N.N. Lebedev, I.S. Uflyand, \
Prikladnaya Matematica Mehanica 22 (1958) 320\n  ",
  FontSize->10]
}], "Subsubtitle",
 CellChangeTimes->{{3.571405445916532*^9, 3.571405608883275*^9}, {
  3.571589785499888*^9, 3.571589800371077*^9}}],

Cell[CellGroupData[{

Cell["Load the Tensor2Analysis.m Package", "Subsection",
 CellChangeTimes->{{3.571405640018538*^9, 3.5714056481776752`*^9}, {
  3.5715930862409687`*^9, 3.571593086573926*^9}}],

Cell[TextData[{
 "The Tensor2Analysis.m is an ressource file for the book ",
 StyleBox["A. Constantinescu and A.M. Korsunsky - Elasticity with \
Mathematica, Cambridge University Press, 2007 ",
  FontSlant->"Italic"],
 "and can be downloaded from the webpages of the publisher: \n\n",
 ButtonBox["http://www.cambridge.org/aus/catalogue/catalogue.asp?isbn=\
9780521842013&ss=res",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.cambridge.org/aus/catalogue/catalogue.asp?isbn=\
9780521842013&ss=res"], None},
  ButtonNote->
   "http://www.cambridge.org/aus/catalogue/catalogue.asp?isbn=9780521842013&\
ss=res"],
 "\n\nor  the webpage of authors."
}], "Text",
 CellChangeTimes->{{3.571593719807003*^9, 3.5715938657499866`*^9}, {
  3.571593918533176*^9, 3.5715939535445232`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", 
  "\"\</mydata/constant/Elastica/ElasticaBook/Packages\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Tensor2Analysis.m"}]}], "Input",
 CellChangeTimes->{{3.418699575369896*^9, 3.418699618623175*^9}, {
   3.41869965510644*^9, 3.418699691347876*^9}, {3.418699843106048*^9, 
   3.418699913607731*^9}, 3.420258739547962*^9, {3.423442105468604*^9, 
   3.423442106874854*^9}, {3.436700805385072*^9, 3.436700856395807*^9}, {
   3.469442022281114*^9, 3.469442027206057*^9}, {3.5715930210146503`*^9, 
   3.571593024669118*^9}}],

Cell[BoxData["\<\"/mydata/constant/Elastica/ElasticaBook/Packages\"\>"], \
"Output",
 CellChangeTimes->{
  3.4234484626814013`*^9, 3.436700726730472*^9, {3.436700838032414*^9, 
   3.436700883518293*^9}, 3.469442029371649*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define coordinate systems", "Subsection",
 CellChangeTimes->{{3.420238858181666*^9, 3.420238911332079*^9}, {
  3.57159397830614*^9, 3.5715939859625483`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.420176509748687*^9, 3.420176523506941*^9}, {
  3.4204290484109216`*^9, 3.4204290499108257`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.418699769880905*^9, 3.418699806256644*^9}, {
  3.418700090523372*^9, 3.418700091285981*^9}}],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output",
 CellChangeTimes->{3.420420617447608*^9, 3.4204276349818554`*^9, 
  3.4204290541996136`*^9, 3.4204303787320833`*^9, 3.423442114812354*^9, 
  3.4234484665876513`*^9, 3.436700726997131*^9, 3.436700883798044*^9, 
  3.469442035173464*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "z"}], "}"}]], "Output",
 CellChangeTimes->{3.420420617447608*^9, 3.4204276349818554`*^9, 
  3.4204290541996136`*^9, 3.4204303787320833`*^9, 3.423442114812354*^9, 
  3.4234484665876513`*^9, 3.436700726997131*^9, 3.436700883798044*^9, 
  3.469442035186913*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Displacement and stresses in the layers from Papkovich-Neuber Potentials\
\>", "Subsection",
 CellChangeTimes->{{3.420238858181666*^9, 3.420238911332079*^9}, {
  3.571593990151183*^9, 3.571594001588049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Psi]", "[", "i_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"A1", "[", "i", "]"}], " ", ",", "  ", 
       RowBox[{"A2", "[", "i", "]"}]}], "}"}], "  ", ".", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cosh", "[", " ", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", " ", 
          RowBox[{"z", " ", "-", " ", 
           RowBox[{"h", "[", 
            RowBox[{"i", "-", "1"}], "]"}]}], " ", ")"}]}], "]"}], " ", ",", 
       " ", 
       RowBox[{"Sinh", "[", " ", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", " ", 
          RowBox[{"z", " ", "-", " ", 
           RowBox[{"h", "[", 
            RowBox[{"i", "-", "1"}], "]"}]}], " ", ")"}]}], "]"}]}], " ", 
      "}"}]}], "  ", 
    RowBox[{
     RowBox[{
      StyleBox["BesselJ",
       FontWeight->"Plain"], 
      StyleBox["[",
       FontWeight->"Plain"], 
      RowBox[{
       StyleBox["0",
        FontWeight->"Plain"], 
       StyleBox[",",
        FontWeight->"Plain"], 
       RowBox[{"\[Lambda]", "  ", "r"}]}], " ", "]"}], " ", "/", 
     StyleBox[
      RowBox[{" ", 
       StyleBox[" ",
        FontWeight->"Plain"], " "}]], 
     RowBox[{"Sinh", "[", " ", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"h", "[", "i", "]"}], " ", "-", " ", 
         RowBox[{"h", "[", 
          RowBox[{"i", "-", "1"}], "]"}]}], " ", ")"}]}], "]"}]}]}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]", "[", "i_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"A4", "[", "i", "]"}], " ", ",", "  ", 
      RowBox[{"A3", "[", "i", "]"}]}], "}"}], " ", ".", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cosh", "[", " ", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", " ", 
         RowBox[{"z", " ", "-", " ", 
          RowBox[{"h", "[", 
           RowBox[{"i", "-", "1"}], "]"}]}], " ", ")"}]}], "]"}], " ", ",", 
      " ", 
      RowBox[{"Sinh", "[", " ", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", " ", 
         RowBox[{"z", " ", "-", " ", 
          RowBox[{"h", "[", 
           RowBox[{"i", "-", "1"}], "]"}]}], " ", ")"}]}], "]"}]}], " ", 
     "}"}]}], "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["BesselJ",
       FontWeight->"Plain"], 
      StyleBox["[",
       FontWeight->"Plain"], 
      RowBox[{
       StyleBox["0",
        FontWeight->"Plain"], 
       StyleBox[",",
        FontWeight->"Plain"], 
       RowBox[{"\[Lambda]", "  ", "r"}]}], " ", "]"}], " ", "/", " ", 
     "\[Lambda]"}], "  ", "/", 
    StyleBox[
     RowBox[{
      StyleBox[" ",
       FontWeight->"Plain"], " "}]], 
    RowBox[{"Sinh", "[", " ", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"h", "[", "i", "]"}], " ", "-", " ", 
        RowBox[{"h", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], " ", ")"}]}], "]"}], 
    " "}]}]}]}], "Input",
 CellChangeTimes->{{3.420173375448308*^9, 3.420173383698549*^9}, {
  3.42017349207757*^9, 3.420173530291373*^9}, {3.420173592193551*^9, 
  3.420173796053129*^9}, {3.420173834002172*^9, 3.420173867286957*^9}, {
  3.420173929077202*^9, 3.420173957668673*^9}, {3.420176381356717*^9, 
  3.420176437261079*^9}, {3.420176639410258*^9, 3.420176640992037*^9}, {
  3.4204205805564146`*^9, 3.4204205806130514`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BesselJ", "[", 
   RowBox[{"0", ",", 
    RowBox[{"r", " ", "\[Lambda]"}]}], "]"}], " ", 
  RowBox[{"Csch", "[", 
   RowBox[{"\[Lambda]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"h", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
      RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"Cosh", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"Sinh", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.420420619804879*^9, 3.420427636676083*^9, 
  3.420429060823213*^9, 3.420430381498508*^9, 3.423442116781104*^9, 
  3.4234484682126513`*^9, 3.436700727110392*^9, 3.43670088384681*^9, 
  3.469442037136544*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"BesselJ", "[", 
    RowBox[{"0", ",", 
     RowBox[{"r", " ", "\[Lambda]"}]}], "]"}], " ", 
   RowBox[{"Csch", "[", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
       RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"A4", "[", "i", "]"}], " ", 
      RowBox[{"Cosh", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A3", "[", "i", "]"}], " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}]}], 
    ")"}]}], "\[Lambda]"]], "Output",
 CellChangeTimes->{3.420420619804879*^9, 3.420427636676083*^9, 
  3.420429060823213*^9, 3.420430381498508*^9, 3.423442116781104*^9, 
  3.4234484682126513`*^9, 3.436700727110392*^9, 3.43670088384681*^9, 
  3.46944203715039*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Laplacian", "[", " ", 
   RowBox[{"\[Psi]", "[", "i", "]"}], " ", "]"}], " ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Laplacian", "[", " ", 
   RowBox[{"\[Phi]", "[", "i", "]"}], "  ", "]"}], " ", "]"}]}], "Input",
 CellChangeTimes->{{3.420173968699999*^9, 3.420174027483061*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.420427638293167*^9, 3.436700727667786*^9, 
  3.4367008843323*^9, 3.469442038756844*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.420427638293167*^9, 3.436700727667786*^9, 
  3.4367008843323*^9, 3.469442038885688*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"psi", "[", "i_", "]"}], "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "0", ",", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}], 
     RowBox[{"\[Psi]", "[", "i", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"phi", "[", "i_", "]"}], "=", " ", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", " ", 
     RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}], " ", 
   RowBox[{"\[Phi]", "[", "i", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"pos", " ", "=", 
  RowBox[{"{", 
   RowBox[{"r", ",", "0", ",", "z"}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.42017411421475*^9, 3.420174118574666*^9}, {
  3.42017608027342*^9, 3.420176099125979*^9}, {3.420176582773072*^9, 
  3.420176610691928*^9}, {3.420176654046436*^9, 3.420176655102627*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"4", " ", 
    RowBox[{"BesselJ", "[", 
     RowBox[{"0", ",", 
      RowBox[{"r", " ", "\[Lambda]"}]}], "]"}], " ", 
    RowBox[{"Csch", "[", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A1", "[", "i", "]"}], " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A2", "[", "i", "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.420420621777409*^9, 3.420427639532346*^9, 
  3.420429063567178*^9, 3.42043038392804*^9, 3.423442121421729*^9, 
  3.4234484696032763`*^9, 3.436700728075139*^9, 3.43670088486975*^9, 
  3.469442039983506*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   RowBox[{"BesselJ", "[", 
    RowBox[{"0", ",", 
     RowBox[{"r", " ", "\[Lambda]"}]}], "]"}], " ", 
   RowBox[{"Csch", "[", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
       RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"A4", "[", "i", "]"}], " ", 
      RowBox[{"Cosh", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A3", "[", "i", "]"}], " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}]}], 
    ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}], "\[Lambda]"]], "Output",
 CellChangeTimes->{3.420420621777409*^9, 3.420427639532346*^9, 
  3.420429063567178*^9, 3.42043038392804*^9, 3.423442121421729*^9, 
  3.4234484696032763`*^9, 3.436700728075139*^9, 3.43670088486975*^9, 
  3.469442039993883*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "0", ",", "z"}], "}"}]], "Output",
 CellChangeTimes->{3.420420621777409*^9, 3.420427639532346*^9, 
  3.420429063567178*^9, 3.42043038392804*^9, 3.423442121421729*^9, 
  3.4234484696032763`*^9, 3.436700728075139*^9, 3.43670088486975*^9, 
  3.469442040102436*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", "i_", "]"}], "=", 
  RowBox[{
   RowBox[{"1", " ", "/", " ", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}]}], ")"}]}], " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"psi", "[", "i", "]"}], "-", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"4", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}], ")"}]}], 
      RowBox[{"Grad", "[", 
       RowBox[{
        RowBox[{"Dot", "[", 
         RowBox[{"pos", ",", 
          RowBox[{"psi", "[", "i", "]"}]}], "]"}], "+", 
        RowBox[{"phi", "[", "i", "]"}]}], "]"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.420174127764507*^9, 3.420174128520611*^9}, {
   3.420174265091487*^9, 3.420174280832261*^9}, {3.4201743668527*^9, 
   3.420174382528096*^9}, 3.420174492504017*^9, {3.420175065764807*^9, 
   3.420175067978853*^9}, {3.420176451306924*^9, 3.420176453446494*^9}, {
   3.420176664281717*^9, 3.420176684746902*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
     RowBox[{
      RowBox[{"BesselJ", "[", 
       RowBox[{"1", ",", 
        RowBox[{"r", " ", "\[Lambda]"}]}], "]"}], " ", 
      RowBox[{"Csch", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
          RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"z", " ", "\[Lambda]", " ", 
            RowBox[{"A1", "[", "i", "]"}]}], "+", 
           RowBox[{"A4", "[", "i", "]"}]}], ")"}], " ", 
         RowBox[{"Cosh", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"z", " ", "\[Lambda]", " ", 
            RowBox[{"A2", "[", "i", "]"}]}], "+", 
           RowBox[{"A3", "[", "i", "]"}]}], ")"}], " ", 
         RowBox[{"Sinh", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}]}], 
       ")"}]}]}]}], ",", "0", ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
    RowBox[{
     RowBox[{"BesselJ", "[", 
      RowBox[{"0", ",", 
       RowBox[{"r", " ", "\[Lambda]"}]}], "]"}], " ", 
     RowBox[{"Csch", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"z", " ", "\[Lambda]", " ", 
           RowBox[{"A2", "[", "i", "]"}]}], "+", 
          RowBox[{"A3", "[", "i", "]"}], "+", 
          RowBox[{
           RowBox[{"A1", "[", "i", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"z", " ", "\[Lambda]", " ", 
           RowBox[{"A1", "[", "i", "]"}]}], "+", 
          RowBox[{"A4", "[", "i", "]"}], "+", 
          RowBox[{
           RowBox[{"A2", "[", "i", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.420420628339489*^9, 3.4204276435311127`*^9, 
  3.4204280033098435`*^9, 3.420429076773364*^9, 3.4204303941168413`*^9, 
  3.423442129140479*^9, 3.4234484771189013`*^9, 3.436700733084876*^9, 
  3.436700887494379*^9, 3.469442043229373*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lphi", " ", "=", " ", 
   RowBox[{
    RowBox[{"Laplacian", "[", 
     RowBox[{"\[Phi]", "[", "i", "]"}], "]"}], " ", "\[Equal]", " ", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Lpsi", " ", "=", " ", 
   RowBox[{
    RowBox[{"Laplacian", "[", 
     RowBox[{"\[Psi]", "[", "i", "]"}], "]"}], " ", "\[Equal]", " ", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DrLphi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", 
       RowBox[{"\[Phi]", "[", "i", "]"}], "]"}], ",", " ", "r"}], "]"}], " ", 
    "\[Equal]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DzLphi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", 
       RowBox[{"\[Phi]", "[", "i", "]"}], "]"}], ",", " ", "z"}], "]"}], " ", 
    "\[Equal]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DrLpsi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", 
       RowBox[{"\[Psi]", "[", "i", "]"}], "]"}], ",", " ", "r"}], "]"}], " ", 
    "\[Equal]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DzLpsi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", 
       RowBox[{"\[Psi]", "[", "i", "]"}], "]"}], ",", " ", "z"}], "]"}], " ", 
    "\[Equal]", " ", "0"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.420174003869234*^9, 3.42017400469308*^9}, {
  3.420174612441347*^9, 3.420174695137487*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eps", "[", "i_", "]"}], " ", "=", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "2"}], " ", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Grad", "[", 
         RowBox[{"u", "[", "i", "]"}], "]"}], " ", "+", " ", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Grad", "[", 
          RowBox[{"u", "[", "i", "]"}], "]"}], "]"}]}], " ", ")"}]}], " ", 
     ",", " ", 
     RowBox[{"Assumptions", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Lphi", ",", " ", "Lpsi"}], "}"}]}]}], " ", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.419119337833458*^9, 3.419119437712883*^9}, {
  3.420173966790114*^9, 3.420173967089374*^9}, {3.420174766635456*^9, 
  3.420174816754212*^9}, {3.420175073131649*^9, 3.420175074054412*^9}, {
  3.420175176438254*^9, 3.420175181483227*^9}, {3.420176734294256*^9, 
  3.420176736003122*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sig", "[", "i_", "]"}], " ", "=", 
   RowBox[{"2", " ", 
    RowBox[{"\[Mu]", "[", "i", "]"}], "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Nu]", "[", "i", "]"}], " ", "/", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "  ", 
       RowBox[{"Tr", "[", 
        RowBox[{"eps", "[", "i", "]"}], "]"}], " ", 
       RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
      RowBox[{"eps", "[", "i", "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.420174848189881*^9, {3.420174900294201*^9, 3.420174947110723*^9}, {
   3.420175025186636*^9, 3.42017504248471*^9}, {3.420175076923241*^9, 
   3.420175077886782*^9}, {3.420175190499518*^9, 3.420175194984517*^9}, 
   3.420176740291593*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"Div", "[", " ", 
     RowBox[{"sig", "[", "i", "]"}], " ", "]"}], " ", ",", " ", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lphi", ",", " ", "DrLphi", " ", ",", " ", "DzLphi", " ", ",", " ", 
       "Lpsi", ",", " ", "DrLpsi", ",", " ", "DzLpsi"}], "}"}]}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.420175206228811*^9, 3.420175207252607*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.436700770339099*^9, 3.436700898728657*^9, 
  3.469442057822936*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions between layers: bonded", "Subsection",
 CellChangeTimes->{{3.420175232954726*^9, 3.420175251403943*^9}, {
  3.420249151508573*^9, 3.42024915578962*^9}, {3.469442059255202*^9, 
  3.469442063929987*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lh", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"u", "[", "i", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", " ", 
         RowBox[{
          RowBox[{"u", "[", 
           RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "   ", ")"}], "  ", "/", " ", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"1", ",", 
         RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "  ", ",", "  ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"u", "[", "i", "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", " ", 
         RowBox[{
          RowBox[{"u", "[", 
           RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "   ", ")"}], "  ", "/", " ", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "    ", ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"sig", "[", "i", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}], "-", " ", 
         RowBox[{
          RowBox[{"sig", "[", 
           RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "   ", ")"}], " ", "/", 
       " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"0", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}], "  ", 
      ",", "  ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"sig", "[", "i", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", " ", 
         RowBox[{
          RowBox[{"sig", "[", 
           RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "   ", ")"}], " ", "/", 
       " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"1", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}]}], "  ", 
     "}"}], " ", "/.", " ", 
    RowBox[{"z", " ", "\[Rule]", " ", 
     RowBox[{"h", "[", "i", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.420175253018767*^9, 3.420175253231135*^9}, {
  3.420175287971042*^9, 3.420175358228281*^9}, {3.420175405922217*^9, 
  3.420175448041567*^9}, {3.420175578368702*^9, 3.420175599146035*^9}, {
  3.420176764644205*^9, 3.420176834076568*^9}, {3.42017694474711*^9, 
  3.420176981116362*^9}, {3.420239591197513*^9, 3.420239622998512*^9}, {
  3.420248581482562*^9, 3.42024859741242*^9}, {3.420248640225646*^9, 
  3.420248703807555*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
      RowBox[{"\[Mu]", "[", 
       RowBox[{"1", "+", "i"}], "]"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", "i", "]"}]}], "+", 
           RowBox[{"h", "[", 
            RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", 
          RowBox[{"1", "+", "i"}], "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A1", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}]}], ")"}], " ", 
       RowBox[{"\[Mu]", "[", "i", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A3", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A4", "[", "i", "]"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"A1", "[", "i", "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Mu]", "[", "i", "]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{
          RowBox[{"A3", "[", "i", "]"}], " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"4", " ", 
                RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "i", "]"}], "-", 
            RowBox[{"h", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A3", "[", 
           RowBox[{"1", "+", "i"}], "]"}], "+", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"A2", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"h", "[", "i", "]"}]}], "+", 
          RowBox[{
           RowBox[{"A1", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Nu]", "[", 
               RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"1", "+", "i"}], "]"}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"A3", "[", "i", "]"}], "+", 
    RowBox[{
     RowBox[{"A4", "[", "i", "]"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Csch", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "[", "i", "]"}], "-", 
         RowBox[{"h", "[", 
          RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A4", "[", 
        RowBox[{"1", "+", "i"}], "]"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"A1", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"A2", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"A4", "[", "i", "]"}]}], "+", 
    RowBox[{
     RowBox[{"A3", "[", "i", "]"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"Csch", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "[", "i", "]"}], "-", 
         RowBox[{"h", "[", 
          RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A3", "[", 
        RowBox[{"1", "+", "i"}], "]"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"A2", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{
        RowBox[{"A1", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", 
            RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4234423234933925`*^9, 3.436700835417637*^9, 
  3.436700964085692*^9, 3.469442130666455*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Solve", "[", "  ", 
   RowBox[{
    RowBox[{"Thread", "[", " ", 
     RowBox[{"lh", " ", "==", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A1", "[", "i", "]"}], ",", 
      RowBox[{"A2", "[", "i", "]"}], ",", 
      RowBox[{"A3", "[", "i", "]"}], ",", 
      RowBox[{"A4", "[", "i", "]"}]}], "}"}]}], " ", "]"}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.420248740040341*^9, 3.420248747641995*^9}, {
  3.42042058062184*^9, 3.4204205806325817`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", 
        RowBox[{"\[Mu]", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", "i", "]"}], "-", 
           RowBox[{"h", "[", 
            RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A3", "[", 
             RowBox[{"1", "+", "i"}], "]"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"A2", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}]}], ")"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", "[", "i", "]"}], "-", 
            RowBox[{"\[Mu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"A4", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sinh", "[", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
               RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
            RowBox[{"\[Mu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"A2", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"\[Mu]", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"\[Nu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"A2", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", " ", "\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"\[Mu]", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"\[Nu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}], " ", 
             SuperscriptBox[
              RowBox[{"Sinh", "[", 
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                  RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", 
        RowBox[{"\[Mu]", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", "i", "]"}], "-", 
           RowBox[{"h", "[", 
            RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A3", "[", 
              RowBox[{"1", "+", "i"}], "]"}], "+", 
             RowBox[{"\[Lambda]", " ", 
              RowBox[{"A2", "[", 
               RowBox[{"1", "+", "i"}], "]"}], " ", 
              RowBox[{"h", "[", "i", "]"}]}]}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", "[", "i", "]"}], "-", 
            RowBox[{"\[Mu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"Cosh", "[", 
           RowBox[{"2", " ", "\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A3", "[", 
             RowBox[{"1", "+", "i"}], "]"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"A2", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", "[", "i", "]"}], "-", 
            RowBox[{"\[Mu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A4", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"A2", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"\[Mu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"\[Nu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"\[Mu]", "[", "i", "]"}]}], "-", 
            RowBox[{"\[Mu]", "[", 
             RowBox[{"1", "+", "i"}], "]"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
             RowBox[{"\[Nu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Mu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"\[Nu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"A3", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", 
        RowBox[{"\[Mu]", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", "i", "]"}], "-", 
           RowBox[{"h", "[", 
            RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"A4", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", " ", "\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"A3", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], "+", 
                RowBox[{"\[Lambda]", " ", 
                 RowBox[{"A2", "[", 
                  RowBox[{"1", "+", "i"}], "]"}], " ", 
                 RowBox[{"h", "[", "i", "]"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Mu]", "[", "i", "]"}], "-", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"A1", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}], "-", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"h", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"A3", "[", 
                RowBox[{"1", "+", "i"}], "]"}], "+", 
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"A2", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"h", "[", "i", "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Mu]", "[", "i", "]"}], "-", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"A1", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A3", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"3", "-", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"A2", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{"A1", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["\[Lambda]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"h", "[", "i", "]"}], "2"]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["\[Lambda]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"h", "[", "i", "]"}], "2"]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"A4", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", 
        RowBox[{"\[Mu]", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", "i", "]"}], "-", 
           RowBox[{"h", "[", 
            RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"A4", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}], " ", 
             SuperscriptBox[
              RowBox[{"Sinh", "[", 
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                  RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Mu]", "[", "i", "]"}], "-", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A3", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"\[Mu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}]}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
               RowBox[{"\[Mu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"\[Mu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Mu]", "[", 
                 RowBox[{"1", "+", "i"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}],
            ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A2", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"\[Mu]", "[", "i", "]"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"h", "[", "i", "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{"\[Mu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"h", "[", "i", "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}], "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", 
           RowBox[{"1", "+", "i"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Mu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SuperscriptBox["\[Lambda]", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"h", "[", "i", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"]}], 
               "+", 
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"h", "[", "i", "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["\[Lambda]", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"h", "[", "i", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"]}], 
               "+", 
               RowBox[{"\[Lambda]", " ", 
                RowBox[{"h", "[", "i", "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}], "-", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                    RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"\[Nu]", "[", 
                    RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.423442533672323*^9, 3.436701027205867*^9, 
  3.469442193752605*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions between layers: sliding", "Subsection",
 CellChangeTimes->{{3.420175232954726*^9, 3.420175251403943*^9}, {
  3.420249151508573*^9, 3.420249175277685*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"u", "[", "i", "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", " ", 
         RowBox[{
          RowBox[{"u", "[", 
           RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "   ", ")"}], "  ", "/", " ", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "    ", ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"sig", "[", "i", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}], "-", " ", 
         RowBox[{
          RowBox[{"sig", "[", 
           RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "   ", ")"}], " ", "/", 
       " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"0", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}], "  ", 
      ",", "  ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"sig", "[", "i", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "/", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"1", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}], ",", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"i", " ", "+", " ", "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "  ", "/", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"1", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}]}], "  ", 
     "}"}], " ", "/.", " ", 
    RowBox[{"z", " ", "\[Rule]", " ", 
     RowBox[{"h", "[", "i", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.420175253018767*^9, 3.420175253231135*^9}, {
   3.420175287971042*^9, 3.420175358228281*^9}, {3.420175405922217*^9, 
   3.420175448041567*^9}, {3.420175578368702*^9, 3.420175599146035*^9}, {
   3.420176764644205*^9, 3.420176834076568*^9}, {3.42017694474711*^9, 
   3.420176981116362*^9}, {3.420239591197513*^9, 3.420239622998512*^9}, {
   3.420248581482562*^9, 3.42024859741242*^9}, {3.420248640225646*^9, 
   3.420248703807555*^9}, {3.420249346504487*^9, 3.420249348901588*^9}, {
   3.42024942260684*^9, 3.420249451218342*^9}, 3.4204274567227573`*^9, 
   3.469445642024837*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Mu]", "[", "i", "]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{
          RowBox[{"A3", "[", "i", "]"}], " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"4", " ", 
                RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "i", "]"}], "-", 
            RowBox[{"h", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A3", "[", 
           RowBox[{"1", "+", "i"}], "]"}], "+", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"A2", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"h", "[", "i", "]"}]}], "+", 
          RowBox[{
           RowBox[{"A1", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Nu]", "[", 
               RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"1", "+", "i"}], "]"}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"A3", "[", "i", "]"}], "+", 
    RowBox[{
     RowBox[{"A4", "[", "i", "]"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Csch", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "[", "i", "]"}], "-", 
         RowBox[{"h", "[", 
          RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A4", "[", 
        RowBox[{"1", "+", "i"}], "]"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"A1", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"A2", "[", 
         RowBox[{"1", "+", "i"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"Csch", "[", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A3", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Csch", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{"h", "[", 
          RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A3", "[", 
       RowBox[{"1", "+", "i"}], "]"}], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"A2", "[", 
        RowBox[{"1", "+", "i"}], "]"}], " ", 
       RowBox[{"h", "[", "i", "]"}]}], "+", 
      RowBox[{
       RowBox[{"A1", "[", 
        RowBox[{"1", "+", "i"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436701027739115*^9, 3.469442200110592*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Solve", "[", "  ", 
   RowBox[{
    RowBox[{"Thread", "[", " ", 
     RowBox[{"lhs", " ", "==", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A1", "[", "i", "]"}], ",", 
      RowBox[{"A2", "[", "i", "]"}], ",", 
      RowBox[{"A3", "[", "i", "]"}], ",", 
      RowBox[{"A4", "[", "i", "]"}]}], "}"}]}], " ", "]"}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{3.469442178292935*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"svars\"\>"}], ":", 
  " ", "\<\"Equations may not give solutions for all \\\"solve\\\" variables. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Solve/svars\\\", \
ButtonNote -> \\\"Solve::svars\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.469442205840132*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.46944274455686*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{
    RowBox[{"CoefficientArrays", "[", " ", 
     RowBox[{"lhs", " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"A1", "[", "i", "]"}], ",", 
        RowBox[{"A2", "[", "i", "]"}], ",", 
        RowBox[{"A3", "[", "i", "]"}], ",", 
        RowBox[{"A4", "[", "i", "]"}]}], "}"}]}], " ", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "//", " ", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.469443020387786*^9, 3.469443021116833*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       FractionBox[
        RowBox[{
         RowBox[{"Csch", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h", "[", "i", "]"}], "-", 
             RowBox[{"h", "[", 
              RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A3", "[", 
            RowBox[{"1", "+", "i"}], "]"}], "+", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"A2", "[", 
             RowBox[{"1", "+", "i"}], "]"}], " ", 
            RowBox[{"h", "[", "i", "]"}]}], "+", 
           RowBox[{
            RowBox[{"A1", "[", 
             RowBox[{"1", "+", "i"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"4", " ", 
               RowBox[{"\[Nu]", "[", 
                RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"\[Mu]", "[", 
          RowBox[{"1", "+", "i"}], "]"}]}]]},
      {
       RowBox[{
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "i", "]"}], "-", 
            RowBox[{"h", "[", 
             RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A4", "[", 
           RowBox[{"1", "+", "i"}], "]"}], "+", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"A1", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"h", "[", "i", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"A2", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"\[Nu]", "[", 
              RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}]}], ")"}]}]},
      {"0"},
      {
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Csch", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"h", "[", "i", "]"}]}], "+", 
             RowBox[{"h", "[", 
              RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], "]"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A3", "[", 
           RowBox[{"1", "+", "i"}], "]"}], "+", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"A2", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"h", "[", "i", "]"}]}], "+", 
          RowBox[{
           RowBox[{"A1", "[", 
            RowBox[{"1", "+", "i"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"\[Nu]", "[", 
               RowBox[{"1", "+", "i"}], "]"}]}]}], ")"}]}]}], ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.46944302177178*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{
    RowBox[{"CoefficientArrays", "[", " ", 
     RowBox[{"lhs", " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"A1", "[", "i", "]"}], ",", 
        RowBox[{"A2", "[", "i", "]"}], ",", 
        RowBox[{"A3", "[", "i", "]"}], ",", 
        RowBox[{"A4", "[", "i", "]"}]}], "}"}]}], " ", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "//", " ", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.469442753104275*^9, 3.46944276259052*^9}, {
  3.469442797097123*^9, 3.46944284560022*^9}, {3.469442990278887*^9, 
  3.469442995061218*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"h", "[", "i", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Coth", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
             RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"4", " ", 
            RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Coth", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
             RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
         RowBox[{"h", "[", "i", "]"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"\[Nu]", "[", "i", "]"}]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
      FractionBox[
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]]},
     {
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], "1", 
      RowBox[{"Coth", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
          RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]},
     {
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]"}], " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], 
      RowBox[{"-", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], 
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}]},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.469442823251449*^9, 3.46944284619744*^9}, 
   3.469442996308648*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Displacement and stresses in the halfspace", "Subsection",
 CellChangeTimes->{{3.420238858181666*^9, 3.420238893724455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]f", " ", "=", " ", 
   RowBox[{"A5", "  ", 
    RowBox[{"Exp", "[", " ", 
     RowBox[{
      RowBox[{"-", " ", "\[Lambda]"}], " ", 
      RowBox[{"(", " ", 
       RowBox[{"z", " ", "-", " ", "hf"}], " ", ")"}]}], "]"}], "   ", 
    RowBox[{
     StyleBox["BesselJ",
      FontWeight->"Plain"], 
     StyleBox["[",
      FontWeight->"Plain"], 
     RowBox[{
      StyleBox["0",
       FontWeight->"Plain"], 
      StyleBox[",",
       FontWeight->"Plain"], 
      RowBox[{"\[Lambda]", "  ", "r"}]}], " ", "]"}]}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"\[Phi]f", " ", "=", " ", 
  RowBox[{"A6", "  ", 
   RowBox[{"Exp", "[", " ", 
    RowBox[{
     RowBox[{"-", " ", "\[Lambda]"}], " ", 
     RowBox[{"(", " ", 
      RowBox[{"z", " ", "-", " ", "hf"}], " ", ")"}]}], "]"}], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["BesselJ",
      FontWeight->"Plain"], 
     StyleBox["[",
      FontWeight->"Plain"], 
     RowBox[{
      StyleBox["0",
       FontWeight->"Plain"], 
      StyleBox[",",
       FontWeight->"Plain"], 
      RowBox[{"\[Lambda]", "  ", "r"}]}], " ", "]"}], "   ", "/", " ", 
    "\[Lambda]", "  "}]}]}]}], "Input",
 CellChangeTimes->{{3.420173375448308*^9, 3.420173383698549*^9}, {
  3.42017349207757*^9, 3.420173530291373*^9}, {3.420173592193551*^9, 
  3.420173796053129*^9}, {3.420173834002172*^9, 3.420173867286957*^9}, {
  3.420173929077202*^9, 3.420173957668673*^9}, {3.420176381356717*^9, 
  3.420176437261079*^9}, {3.420176639410258*^9, 3.420176640992037*^9}, {
  3.420238931920778*^9, 3.420239048669091*^9}, {3.420239079163087*^9, 
  3.420239108704196*^9}, {3.420239430999259*^9, 3.420239431619895*^9}}],

Cell[BoxData[
 RowBox[{"A5", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "hf"}], "+", "z"}], ")"}]}], " ", "\[Lambda]"}]], " ", 
  RowBox[{"BesselJ", "[", 
   RowBox[{"0", ",", 
    RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.4204210856568985`*^9, 3.420427572692874*^9, 
  3.420427936104184*^9, 3.420429367560416*^9, 3.423442651946089*^9, 
  3.4234485044470263`*^9, 3.436701027785835*^9, 3.469446240236303*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"A6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "hf"}], "+", "z"}], ")"}]}], " ", "\[Lambda]"}]], " ", 
   RowBox[{"BesselJ", "[", 
    RowBox[{"0", ",", 
     RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "\[Lambda]"]], "Output",
 CellChangeTimes->{3.4204210856568985`*^9, 3.420427572692874*^9, 
  3.420427936104184*^9, 3.420429367560416*^9, 3.423442651946089*^9, 
  3.4234485044470263`*^9, 3.436701027785835*^9, 3.469446240250849*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Laplacian", "[", " ", "\[Psi]f", " ", "]"}], " ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Laplacian", "[", " ", "\[Phi]f", "  ", "]"}], " ", "]"}]}], "Input",\

 CellChangeTimes->{{3.420173968699999*^9, 3.420174027483061*^9}, {
  3.420239133423388*^9, 3.420239136001409*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4234485047595263`*^9, 3.436701027959741*^9, 
  3.469446241157658*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4234485047595263`*^9, 3.436701027959741*^9, 
  3.469446241168756*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"psif", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "0", ",", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Nu]f"}], ")"}], "\[Psi]f"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"phif", "=", " ", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", " ", "\[Nu]f"}], ")"}], " ", 
   "\[Phi]f"}]}], "\[IndentingNewLine]", 
 RowBox[{"pos", " ", "=", 
  RowBox[{"{", 
   RowBox[{"r", ",", "0", ",", "z"}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.42017411421475*^9, 3.420174118574666*^9}, {
  3.42017608027342*^9, 3.420176099125979*^9}, {3.420176582773072*^9, 
  3.420176610691928*^9}, {3.420176654046436*^9, 3.420176655102627*^9}, {
  3.420239120206054*^9, 3.420239154085016*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"4", " ", "A5", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "hf"}], "+", "z"}], ")"}]}], " ", "\[Lambda]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Nu]f"}], ")"}], " ", 
    RowBox[{"BesselJ", "[", 
     RowBox[{"0", ",", 
      RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4204210885239024`*^9, 3.4204275743529234`*^9, 
  3.4204279382974033`*^9, 3.4204293708883286`*^9, 3.423442655348215*^9, 
  3.4234485050876513`*^9, 3.436701028043705*^9, 3.469446241993886*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "A6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "hf"}], "+", "z"}], ")"}]}], " ", "\[Lambda]"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Nu]f"}], ")"}], " ", 
   RowBox[{"BesselJ", "[", 
    RowBox[{"0", ",", 
     RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "\[Lambda]"]], "Output",
 CellChangeTimes->{3.4204210885239024`*^9, 3.4204275743529234`*^9, 
  3.4204279382974033`*^9, 3.4204293708883286`*^9, 3.423442655348215*^9, 
  3.4234485050876513`*^9, 3.436701028043705*^9, 3.469446242004112*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "0", ",", "z"}], "}"}]], "Output",
 CellChangeTimes->{3.4204210885239024`*^9, 3.4204275743529234`*^9, 
  3.4204279382974033`*^9, 3.4204293708883286`*^9, 3.423442655348215*^9, 
  3.4234485050876513`*^9, 3.436701028043705*^9, 3.469446242011327*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uf", "=", 
  RowBox[{
   RowBox[{"1", " ", "/", " ", 
    RowBox[{"(", 
     RowBox[{"2", " ", "\[Mu]f"}], ")"}]}], " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"psif", "-", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"4", 
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Nu]f"}], ")"}]}], ")"}]}], 
      RowBox[{"Grad", "[", 
       RowBox[{
        RowBox[{"Dot", "[", 
         RowBox[{"pos", ",", "psif"}], "]"}], "+", "phif"}], "]"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.420174127764507*^9, 3.420174128520611*^9}, {
   3.420174265091487*^9, 3.420174280832261*^9}, {3.4201743668527*^9, 
   3.420174382528096*^9}, 3.420174492504017*^9, {3.420175065764807*^9, 
   3.420175067978853*^9}, {3.420176451306924*^9, 3.420176453446494*^9}, {
   3.420176664281717*^9, 3.420176684746902*^9}, {3.4202394395721*^9, 
   3.420239473855357*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"hf", "-", "z"}], ")"}], " ", "\[Lambda]"}]], " ", 
      RowBox[{"(", 
       RowBox[{"A6", "+", 
        RowBox[{"A5", " ", "z", " ", "\[Lambda]"}]}], ")"}], " ", 
      RowBox[{"BesselJ", "[", 
       RowBox[{"1", ",", 
        RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], 
     RowBox[{"2", " ", "\[Mu]f"}]]}], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"hf", "-", "z"}], ")"}], " ", "\[Lambda]"}]], " ", 
      RowBox[{"(", 
       RowBox[{"A6", "+", 
        RowBox[{"A5", " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"z", " ", "\[Lambda]"}], "-", 
           RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"BesselJ", "[", 
       RowBox[{"0", ",", 
        RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], 
     RowBox[{"2", " ", "\[Mu]f"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4204210923263936`*^9, 3.4204275773390603`*^9, 
  3.4204279398314843`*^9, 3.4204280107165956`*^9, 3.4204293729956155`*^9, 
  3.4234426585599236`*^9, 3.4234485055720263`*^9, 3.436701028283897*^9, 
  3.469446243124876*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lphi", " ", "=", " ", 
   RowBox[{
    RowBox[{"Laplacian", "[", "\[Phi]f", "]"}], " ", "\[Equal]", " ", "0"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Lpsi", " ", "=", " ", 
   RowBox[{
    RowBox[{"Laplacian", "[", "\[Psi]f", "]"}], " ", "\[Equal]", " ", "0"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DrLphi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", "\[Phi]f", "]"}], ",", " ", "r"}], "]"}], " ",
     "\[Equal]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DzLphi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", "\[Phi]f", "]"}], ",", " ", "z"}], "]"}], " ",
     "\[Equal]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DrLpsi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", "\[Psi]f", "]"}], ",", " ", "r"}], "]"}], " ",
     "\[Equal]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DzLpsi", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Laplacian", "[", "\[Psi]f", "]"}], ",", " ", "z"}], "]"}], " ",
     "\[Equal]", " ", "0"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.420174003869234*^9, 3.42017400469308*^9}, {
  3.420174612441347*^9, 3.420174695137487*^9}, {3.420239501744516*^9, 
  3.420239503436124*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"epsf", " ", "=", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "2"}], " ", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Grad", "[", "uf", "]"}], " ", "+", " ", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Grad", "[", "uf", "]"}], "]"}]}], " ", ")"}]}], " ", ",", 
     " ", 
     RowBox[{"Assumptions", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Lphi", ",", " ", "Lpsi"}], "}"}]}]}], " ", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.419119337833458*^9, 3.419119437712883*^9}, {
  3.420173966790114*^9, 3.420173967089374*^9}, {3.420174766635456*^9, 
  3.420174816754212*^9}, {3.420175073131649*^9, 3.420175074054412*^9}, {
  3.420175176438254*^9, 3.420175181483227*^9}, {3.420176734294256*^9, 
  3.420176736003122*^9}, {3.420239503709187*^9, 3.42023952950406*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigf", " ", "=", 
   RowBox[{"2", " ", "\[Mu]f", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Nu]f", " ", "/", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"2", " ", "\[Nu]f"}]}], ")"}]}], "  ", 
       RowBox[{"Tr", "[", "epsf", "]"}], " ", 
       RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", "epsf"}], 
     ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.420174848189881*^9, {3.420174900294201*^9, 3.420174947110723*^9}, {
   3.420175025186636*^9, 3.42017504248471*^9}, {3.420175076923241*^9, 
   3.420175077886782*^9}, {3.420175190499518*^9, 3.420175194984517*^9}, 
   3.420176740291593*^9, {3.420239504325886*^9, 3.420239533249076*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"Div", "[", " ", "sigf", " ", "]"}], " ", ",", " ", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lphi", ",", " ", "DrLphi", " ", ",", " ", "DzLphi", " ", ",", " ", 
       "Lpsi", ",", " ", "DrLpsi", ",", " ", "DzLpsi"}], "}"}]}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.420175206228811*^9, 3.420175207252607*^9}, 
   3.420239506374872*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.436701031146694*^9, 3.469446249571309*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions last layer to half space: bonded", "Subsection",
 CellChangeTimes->{{3.420175232954726*^9, 3.420175251403943*^9}, {
  3.420240067103287*^9, 3.420240077703238*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhf", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", "i", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", " ", 
          RowBox[{"uf", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "   ", ")"}], "  ", "/", " ", 
        RowBox[{"BesselJ", "[", 
         RowBox[{"1", ",", 
          RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "   ", ",", " ", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", "i", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}], "-", " ", 
          RowBox[{"uf", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "   ", ")"}], "  ", "/", " ", 
        RowBox[{"BesselJ", "[", 
         RowBox[{"0", ",", 
          RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "    ", ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"sig", "[", "i", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "3"}], "]"}], "]"}], "-", " ", 
          RowBox[{"sigf", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "   ", ")"}], " ", "/", 
        " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"BesselJ", "[", 
           RowBox[{"0", ",", 
            RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}], " ", 
       ",", "  ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"sig", "[", "i", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", " ", 
          RowBox[{"sigf", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "   ", ")"}], " ", "/", 
        " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"BesselJ", "[", 
           RowBox[{"1", ",", 
            RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}]}], "   ",
       "}"}], " ", "/.", " ", 
     RowBox[{"z", " ", "\[Rule]", " ", "hf"}]}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"h", "[", "i", "]"}], " ", "\[Rule]", " ", "hf"}]}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.420175253018767*^9, 3.420175253231135*^9}, {
   3.420175287971042*^9, 3.420175358228281*^9}, {3.420175405922217*^9, 
   3.420175448041567*^9}, {3.420175578368702*^9, 3.420175599146035*^9}, {
   3.420176764644205*^9, 3.420176834076568*^9}, {3.42017694474711*^9, 
   3.420176981116362*^9}, {3.420239591197513*^9, 3.420239622998512*^9}, {
   3.420239656480839*^9, 3.420239669622375*^9}, {3.420239785917352*^9, 
   3.420239892976564*^9}, {3.42024023094056*^9, 3.420240279519976*^9}, {
   3.420250109220768*^9, 3.42025014764251*^9}, 3.4204275482510786`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]f"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"hf", " ", "\[Lambda]", " ", 
         RowBox[{"A2", "[", "i", "]"}]}], "+", 
        RowBox[{"A3", "[", "i", "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hf", " ", "\[Lambda]", " ", 
            RowBox[{"A1", "[", "i", "]"}]}], "+", 
           RowBox[{"A4", "[", "i", "]"}]}], ")"}], " ", 
         RowBox[{"Coth", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{"hf", "-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}]}], 
       ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"A6", "+", 
        RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}]}], ")"}], " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}]}]}], 
    RowBox[{"2", " ", "\[Mu]f", " ", 
     RowBox[{"\[Mu]", "[", "i", "]"}]}]], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "\[Mu]f", " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]f", " ", 
       RowBox[{"A4", "[", "i", "]"}]}], "+", 
      RowBox[{"\[Mu]f", " ", 
       RowBox[{"A3", "[", "i", "]"}], " ", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"hf", "-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"A6", "+", 
         RowBox[{"A5", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"hf", " ", "\[Lambda]"}], "-", 
            RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
      RowBox[{"\[Mu]f", " ", 
       RowBox[{"A2", "[", "i", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"hf", " ", "\[Lambda]", " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
         "+", 
         RowBox[{"4", " ", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[Mu]f", " ", 
       RowBox[{"A1", "[", "i", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hf", " ", "\[Lambda]"}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
         "+", 
         RowBox[{"4", " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
          
          RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "A5"}], "-", "A6", "-", 
    RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "+", 
    RowBox[{"2", " ", "A5", " ", "\[Nu]f"}], "+", 
    RowBox[{"hf", " ", "\[Lambda]", " ", 
     RowBox[{"A2", "[", "i", "]"}]}], "+", 
    RowBox[{"A3", "[", "i", "]"}], "+", 
    RowBox[{
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"hf", "-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A4", "[", "i", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"A2", "[", "i", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"hf", " ", "\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"hf", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "+", 
       
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "A5"}], "-", "A6", "-", 
    RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "+", 
    RowBox[{"2", " ", "A5", " ", "\[Nu]f"}], "+", 
    RowBox[{"A2", "[", "i", "]"}], "-", 
    RowBox[{"A4", "[", "i", "]"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"hf", " ", "\[Lambda]", " ", 
        RowBox[{"A2", "[", "i", "]"}]}], "+", 
       RowBox[{"A3", "[", "i", "]"}]}], ")"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"hf", "-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"\[Nu]", "[", "i", "]"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "hf"}], " ", "\[Lambda]"}], "+", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"hf", "-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"hf", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4234427046683006`*^9, 3.43670104752218*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"Solve", "[", "  ", 
   RowBox[{
    RowBox[{"Thread", "[", " ", 
     RowBox[{"lhf", " ", "==", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A1", "[", "i", "]"}], ",", 
      RowBox[{"A2", "[", "i", "]"}], ",", 
      RowBox[{"A3", "[", "i", "]"}], ",", 
      RowBox[{"A4", "[", "i", "]"}]}], "}"}]}], " ", "]"}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.420240286759405*^9, 3.420240335990613*^9}, {
   3.420240483348955*^9, 3.420240517044995*^9}, {3.42024955884129*^9, 
   3.42024956600062*^9}, {3.4204205806579704`*^9, 3.4204205806657825`*^9}, 
   3.420432606097892*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Mu]f", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"hf", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], "2"], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Mu]f"}], " ", 
          RowBox[{"(", 
           RowBox[{"A6", "+", 
            RowBox[{"A5", " ", 
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"2", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"\[Mu]f", " ", 
          RowBox[{"(", 
           RowBox[{"A5", "+", "A6", "+", 
            RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
            RowBox[{"2", " ", "A5", " ", "\[Nu]f"}]}], ")"}], " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"A6", "+", 
            RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"A6", "+", 
               RowBox[{"A5", " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", 
                  RowBox[{"hf", " ", "\[Lambda]"}], "-", 
                  RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], 
              "]"}]}]}], ")"}], " ", 
          RowBox[{"\[Mu]", "[", "i", "]"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Mu]f", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"hf", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], "2"], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Mu]f"}], " ", 
          RowBox[{"(", 
           RowBox[{"A5", "+", "A6", "+", 
            RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
            RowBox[{"2", " ", "A5", " ", "\[Nu]f"}]}], ")"}]}], "+", 
         RowBox[{"\[Mu]f", " ", 
          RowBox[{"(", 
           RowBox[{"A6", "+", 
            RowBox[{"A5", " ", 
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"2", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"A6", "+", 
            RowBox[{"A5", " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"A6", "+", 
               RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}]}], ")"}], " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], 
              "]"}]}]}], ")"}], " ", 
          RowBox[{"\[Mu]", "[", "i", "]"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"A3", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Mu]f", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"hf", "-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], "2"], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]f", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"hf", " ", "\[Lambda]", " ", 
             RowBox[{"(", 
              RowBox[{"A5", "+", "A6", "+", 
               RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"2", " ", "A5", " ", "\[Nu]f"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"A6", " ", 
                RowBox[{"(", 
                 RowBox[{"3", "-", 
                  RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "+", 
               RowBox[{"A5", " ", 
                RowBox[{"(", 
                 RowBox[{"3", "-", 
                  RowBox[{"6", " ", "\[Nu]f"}], "+", 
                  RowBox[{"hf", " ", "\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"hf", " ", "\[Lambda]"}], "+", 
                    RowBox[{"2", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}]}]}], 
              ")"}], " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
            "-", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"A5", "+", "A6", "+", 
               RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"2", " ", "A5", " ", "\[Nu]f"}]}], ")"}], " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], 
             " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", 
               RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "-", 
            RowBox[{"A5", " ", "hf", " ", "\[Lambda]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"A6", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "+", 
               RowBox[{"A5", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"hf", " ", "\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "+", 
                  RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
            "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "A6"}], "-", 
               RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"A6", "+", 
                  RowBox[{"A5", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"hf", " ", "\[Lambda]"}], "-", 
                    RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Coth", "[", 
                 RowBox[{"\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{"hf", "-", 
                    RowBox[{"h", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], 
                 "]"}]}]}], ")"}], " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
    ",", 
    RowBox[{
     RowBox[{"A4", "[", "i", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Mu]f", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]], 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"hf", "-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "hf"}], " ", "\[Lambda]", " ", "\[Mu]f", " ", 
          RowBox[{"(", 
           RowBox[{"A5", "+", "A6", "+", 
            RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
            RowBox[{"2", " ", "A5", " ", "\[Nu]f"}]}], ")"}], " ", 
          RowBox[{"Cosh", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}]}], 
         "+", 
         RowBox[{"\[Mu]f", " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{"hf", "-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], " ", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "+", 
            RowBox[{"A5", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"hf", " ", "\[Lambda]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"hf", " ", "\[Lambda]"}], "-", 
                  RowBox[{"2", " ", "\[Nu]f"}]}], ")"}]}], "+", 
               RowBox[{"6", " ", "\[Nu]f"}]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"A5", "+", "A6", "+", 
               RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}], "-", 
               RowBox[{"2", " ", "A5", " ", "\[Nu]f"}]}], ")"}], " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"\[Mu]", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Cosh", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"A6", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", 
                  RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "+", 
               RowBox[{"A5", " ", "hf", " ", "\[Lambda]", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"hf", " ", "\[Lambda]"}], "-", 
                  RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"A6", "+", 
                  RowBox[{"A5", " ", "hf", " ", "\[Lambda]"}]}], ")"}], " ", 
                RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{"hf", "-", 
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}]}], ")"}]}], "]"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{"A6", "-", 
               RowBox[{"A6", " ", "hf", " ", "\[Lambda]"}], "+", 
               RowBox[{"A5", " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", 
                  RowBox[{"hf", " ", "\[Lambda]", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"hf", " ", "\[Lambda]"}]}], ")"}]}], "-", 
                  RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"A6", "+", 
                  RowBox[{"A5", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"hf", " ", "\[Lambda]"}], "-", 
                    RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4234428274993057`*^9, 3.436701080272907*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions last layer to half space: sliding", "Subsection",
 CellChangeTimes->{{3.420175232954726*^9, 3.420175251403943*^9}, {
  3.420240067103287*^9, 3.420240077703238*^9}, {3.469445102828779*^9, 
  3.469445105306643*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"u", "[", "i", "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", " ", 
         RowBox[{"uf", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "   ", ")"}], "  ", "/", " ", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], "    ", ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"sig", "[", "i", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}], "-", " ", 
         RowBox[{"sigf", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "   ", ")"}], " ", "/", 
       " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"0", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}], "  ", 
      ",", "  ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"sig", "[", "i", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "/", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"1", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}], ",", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sigf", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "  ", "/", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"1", ",", 
           RowBox[{"r", " ", "\[Lambda]"}]}], "]"}]}], " ", ")"}]}]}], "  ", 
     "}"}], " ", "/.", " ", 
    RowBox[{"z", " ", "\[Rule]", " ", 
     RowBox[{"h", "[", "i", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.469445572612608*^9, {3.469446203961572*^9, 3.469446231300872*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "\[Mu]f", " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"hf", "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{"A6", "+", 
         RowBox[{"A5", " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"4", " ", "\[Nu]f"}]}], ")"}]}], "+", 
         RowBox[{"A5", " ", "\[Lambda]", " ", 
          RowBox[{"h", "[", "i", "]"}]}]}], ")"}], " ", 
       RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
      RowBox[{"\[Mu]f", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{
          RowBox[{"A3", "[", "i", "]"}], " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"4", " ", 
                RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"A3", "[", "i", "]"}], "+", 
    RowBox[{
     RowBox[{"A4", "[", "i", "]"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"hf", "-", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{"A6", "-", 
       RowBox[{"2", " ", "A5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Nu]f"}], ")"}]}], "+", 
       RowBox[{"A5", " ", "\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"Csch", "[", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A3", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{"hf", "-", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"A5", "+", "A6", "-", 
      RowBox[{"2", " ", "A5", " ", "\[Nu]f"}], "+", 
      RowBox[{"A5", " ", "\[Lambda]", " ", 
       RowBox[{"h", "[", "i", "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4234427046683006`*^9, 3.43670104752218*^9, 
  3.469446320359393*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{
    RowBox[{"CoefficientArrays", "[", " ", 
     RowBox[{"lhs", " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"A1", "[", "i", "]"}], ",", 
        RowBox[{"A2", "[", "i", "]"}], ",", 
        RowBox[{"A3", "[", "i", "]"}], ",", 
        RowBox[{"A4", "[", "i", "]"}]}], "}"}]}], " ", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"h", "[", "i", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Coth", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
             RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"4", " ", 
            RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Coth", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"h", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
             RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
         RowBox[{"h", "[", "i", "]"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"\[Nu]", "[", "i", "]"}]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
      FractionBox[
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
      FractionBox["1", 
       RowBox[{"2", " ", 
        RowBox[{"\[Mu]", "[", "i", "]"}]}]]},
     {
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], "1", 
      RowBox[{"Coth", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
          RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]},
     {
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]"}], " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csch", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], 
      RowBox[{"-", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], 
      RowBox[{
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}]},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.469446405830394*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.420175253018767*^9, 3.420175253231135*^9}, {
   3.420175287971042*^9, 3.420175358228281*^9}, {3.420175405922217*^9, 
   3.420175448041567*^9}, {3.420175578368702*^9, 3.420175599146035*^9}, {
   3.420176764644205*^9, 3.420176834076568*^9}, {3.42017694474711*^9, 
   3.420176981116362*^9}, {3.420239591197513*^9, 3.420239622998512*^9}, {
   3.420239656480839*^9, 3.420239669622375*^9}, {3.420239785917352*^9, 
   3.420239892976564*^9}, {3.42024023094056*^9, 3.420240279519976*^9}, {
   3.420250109220768*^9, 3.42025014764251*^9}, 3.4204275482510786`*^9, 
   3.469446272360279*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a6", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"Solve", "[", "  ", 
     RowBox[{
      RowBox[{"Thread", "[", " ", 
       RowBox[{
        RowBox[{"lhs", "[", 
         RowBox[{"[", "4", "]"}], "]"}], " ", "==", " ", "0"}], "]"}], ",", 
      " ", 
      RowBox[{"{", "A6", "}"}]}], " ", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.420240286759405*^9, 3.420240335990613*^9}, {
   3.420240483348955*^9, 3.420240517044995*^9}, {3.42024955884129*^9, 
   3.42024956600062*^9}, {3.4204205806579704`*^9, 3.4204205806657825`*^9}, 
   3.420432606097892*^9, {3.469446294582333*^9, 3.469446295713353*^9}, {
   3.469446465621296*^9, 3.469446511087878*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"A6", "\[Rule]", 
   RowBox[{"A5", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "\[Nu]f"}], "-", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"h", "[", "i", "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4234428274993057`*^9, 3.436701080272907*^9, 3.469446355584277*^9, {
   3.469446494637927*^9, 3.469446514074054*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhss", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"lhs", " ", "/.", " ", "a6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469446527457079*^9, 3.469446548584288*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "\[Mu]f", " ", 
      RowBox[{"\[Mu]", "[", "i", "]"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "A5", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"hf", "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Nu]f"}], ")"}], " ", 
       RowBox[{"\[Mu]", "[", "i", "]"}]}], "+", 
      RowBox[{"\[Mu]f", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{
          RowBox[{"A3", "[", "i", "]"}], " ", 
          RowBox[{"Coth", "[", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"h", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
              RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"4", " ", 
                RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"Coth", "[", 
              RowBox[{"\[Lambda]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
                 RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
             RowBox[{"h", "[", "i", "]"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "A5"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"hf", "-", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}]]}], "+", 
    RowBox[{"A3", "[", "i", "]"}], "+", 
    RowBox[{
     RowBox[{"A4", "[", "i", "]"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"h", "[", "i", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"A1", "[", "i", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Coth", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"Csch", "[", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
            RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A3", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A4", "[", "i", "]"}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"A1", "[", "i", "]"}], " ", 
          RowBox[{"h", "[", "i", "]"}]}], "+", 
         RowBox[{
          RowBox[{"A2", "[", "i", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.469446556119944*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"lhss", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ", 
     
     RowBox[{"A4", "[", "i", "]"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469446595530566*^9, 3.469446642560281*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A4", "[", "i", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"Csch", "[", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
    RowBox[{"Sinh", "[", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
        RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"A1", "[", "i", "]"}]}], " ", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A3", "[", "i", "]"}], " ", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"A2", "[", "i", "]"}], " ", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"h", "[", "i", "]"}]}], "+", 
      RowBox[{
       RowBox[{"A2", "[", "i", "]"}], " ", 
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "-", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"A1", "[", "i", "]"}], " ", 
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"h", "[", "i", "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"A1", "[", "i", "]"}], " ", 
       RowBox[{"Coth", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"\[Nu]", "[", "i", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"A2", "[", "i", "]"}], " ", 
       RowBox[{"Csch", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], " ", 
       RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.469446634933394*^9, 3.469446645455864*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhsss", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"lhss", " ", "/.", " ", "a4"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.469446649083711*^9, 3.469446668502578*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"A5", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{"hf", "-", 
           RowBox[{"h", "[", "i", "]"}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Nu]f"}], ")"}]}], "\[Mu]f"]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A2", "[", "i", "]"}], "-", 
        RowBox[{
         RowBox[{"A1", "[", "i", "]"}], " ", 
         RowBox[{"Coth", "[", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
             RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", "[", "i", "]"}]}], ")"}]}], 
     RowBox[{"\[Mu]", "[", "i", "]"}]]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "A5"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{"hf", "-", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}]]}], "-", 
    RowBox[{"A1", "[", "i", "]"}], "+", 
    RowBox[{
     RowBox[{"A2", "[", "i", "]"}], " ", 
     RowBox[{"Coth", "[", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
         RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}]}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Csch", "[", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h", "[", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
          RowBox[{"h", "[", "i", "]"}]}], ")"}]}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A3", "[", "i", "]"}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"A2", "[", "i", "]"}], " ", 
        RowBox[{"h", "[", "i", "]"}]}], "+", 
       RowBox[{
        RowBox[{"A1", "[", "i", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Nu]", "[", "i", "]"}]}]}], ")"}]}]}], ")"}]}]}], ",", 
   "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.469446675244431*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1129, 664},
WindowMargins->{{Automatic, 23}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 317, 8, 199, "Title"],
Cell[887, 32, 1249, 21, 318, "Subsubtitle"],
Cell[CellGroupData[{
Cell[2161, 57, 175, 2, 39, "Subsection"],
Cell[2339, 61, 790, 18, 131, "Text"],
Cell[CellGroupData[{
Cell[3154, 83, 574, 10, 55, "Input"],
Cell[3731, 95, 225, 4, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4005, 105, 163, 2, 39, "Subsection"],
Cell[4171, 109, 192, 3, 32, "Input"],
Cell[CellGroupData[{
Cell[4388, 116, 389, 8, 55, "Input"],
Cell[4780, 126, 333, 6, 31, "Output"],
Cell[5116, 134, 430, 10, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5595, 150, 217, 4, 39, "Subsection"],
Cell[CellGroupData[{
Cell[5837, 158, 3449, 105, 55, "Input"],
Cell[9289, 265, 1237, 38, 31, "Output"],
Cell[10529, 305, 1298, 39, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11864, 349, 383, 8, 55, "Input"],
Cell[12250, 359, 137, 2, 31, "Output"],
Cell[12390, 363, 137, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12564, 370, 913, 24, 77, "Input"],
Cell[13480, 396, 1488, 44, 31, "Output"],
Cell[14971, 442, 1423, 43, 48, "Output"],
Cell[16397, 487, 310, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16744, 498, 1059, 28, 32, "Input"],
Cell[17806, 528, 3873, 113, 138, "Output"]
}, Open  ]],
Cell[21694, 644, 1585, 46, 143, "Input"],
Cell[23282, 692, 940, 24, 32, "Input"],
Cell[24225, 718, 901, 23, 32, "Input"],
Cell[CellGroupData[{
Cell[25151, 745, 486, 12, 32, "Input"],
Cell[25640, 759, 172, 4, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25861, 769, 227, 3, 39, "Subsection"],
Cell[CellGroupData[{
Cell[26113, 776, 3029, 80, 99, "Input"],
Cell[29145, 858, 9892, 291, 302, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39074, 1154, 632, 17, 32, "Input"],
Cell[39709, 1173, 33300, 862, 619, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[73058, 2041, 180, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[73263, 2047, 2831, 72, 99, "Input"],
Cell[76097, 2121, 8409, 250, 243, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84543, 2376, 559, 16, 32, "Input"],
Cell[85105, 2394, 408, 7, 24, "Message"],
Cell[85516, 2403, 76, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85629, 2409, 534, 14, 32, "Input"],
Cell[86166, 2425, 3520, 102, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89723, 2532, 630, 16, 32, "Input"],
Cell[90356, 2550, 7175, 212, 93, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97580, 2768, 130, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[97735, 2773, 1682, 47, 55, "Input"],
Cell[99420, 2822, 525, 13, 33, "Output"],
Cell[99948, 2837, 563, 14, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100548, 2856, 378, 8, 55, "Input"],
Cell[100929, 2866, 119, 2, 31, "Output"],
Cell[101051, 2870, 119, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101207, 2877, 794, 21, 77, "Input"],
Cell[102004, 2900, 704, 18, 33, "Output"],
Cell[102711, 2920, 664, 17, 50, "Output"],
Cell[103378, 2939, 295, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103710, 2949, 919, 24, 32, "Input"],
Cell[104632, 2975, 1362, 38, 52, "Output"]
}, Open  ]],
Cell[106009, 3016, 1446, 41, 143, "Input"],
Cell[107458, 3059, 887, 21, 32, "Input"],
Cell[108348, 3082, 762, 18, 32, "Input"],
Cell[CellGroupData[{
Cell[109135, 3104, 482, 12, 32, "Input"],
Cell[109620, 3118, 147, 3, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[109816, 3127, 189, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[110030, 3133, 3001, 76, 99, "Input"],
Cell[113034, 3211, 6287, 184, 181, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119358, 3400, 757, 19, 32, "Input"],
Cell[120118, 3421, 14612, 388, 365, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[134779, 3815, 239, 3, 39, "Subsection"],
Cell[CellGroupData[{
Cell[135043, 3822, 2094, 59, 99, "Input"],
Cell[137140, 3883, 7256, 212, 193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144433, 4100, 468, 13, 32, "Input"],
Cell[144904, 4115, 7126, 211, 93, "Output"]
}, Open  ]],
Cell[152045, 4329, 627, 9, 32, "Input"],
Cell[CellGroupData[{
Cell[152697, 4342, 757, 17, 32, "Input"],
Cell[153457, 4361, 429, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153923, 4378, 205, 4, 32, "Input"],
Cell[154131, 4384, 6419, 189, 173, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160587, 4578, 395, 11, 32, "Input"],
Cell[160985, 4591, 4456, 130, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165478, 4726, 217, 4, 32, "Input"],
Cell[165698, 4732, 2506, 78, 86, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
